@@ -1,4 +1,4 @@
-import hw_fortran_t as hw
+import hw_wwj.hw_fortran_t as hw
 #from hw_wwj import hw_fortran_t as hw
 
 def test():
